<?php
/**
 * Plugin Name: Dashboard Forum Activity
 * Description: Quickly review your bbPress forum activity using a widget on your WordPress Dashboard. 
 * Version: 0.2.1
 * Author: ryanimel
 * Author URI: http://wpcandy.com/
 * License: GPL2
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
**/


// Creates the widget output
function rwi_dashboard_forum_activity_output() {
	
	$widget_options = rwi_dashboard_forum_activity_options();
		
	$forums_query = new WP_Query( array( 
		'post_type' => array( 'topic', 'reply' ),
		'showposts' => $widget_options['posts_number'],
		'orderby' => 'date',
		'order' => 'DESC'
	) );
	
	$forums =& $forums_query->posts;

	if ( $forums && is_array( $forums ) ) {
		$list = array();
		foreach ( $forums as $forum ) {
			
			$url_edit = get_edit_post_link( $forum->ID );
			$url_public = get_permalink( $forum->ID );
			$title = _draft_or_post_title( $forum->ID );
			
			$author = bbp_get_topic_author_link( '&size=50&post_id=' . $forum->ID );
			
			if ( 'reply' == get_post_type( $forum->ID ) ) {
				$identifier = 'Reply: ';
			} else if ( 'topic' == get_post_type( $forum->ID ) ) {
				$identifier = 'Topic: ';
			}
			
			$item = "
				$avatar
				
				<div class='dashboard-comment-wrap'>
					
					<h4>$identifier <a href='$url_edit' title='" . sprintf( __( 'Edit "%s"' ), attribute_escape( $title ) ) . "'>$title</a> by $author <a href='$url_public'>#</a></h4>
					
				";
			
			if ( $the_content = preg_split( '#\s#', strip_tags( $forum->post_content ), 11, PREG_SPLIT_NO_EMPTY ) )
				$item .= '<blockquote><p>' . join( ' ', array_slice( $the_content, 0, 10 ) ) . ( 10 < count( $the_content ) ? '&hellip;' : '' ) . '</p></blockquote></div>';
			
			$list[] = $item;
		}
?>
<ul>
	<li class="activity-item"><?php echo join( "</li>\n<li class='activity-item'>", $list ); ?></li>
</ul>
<ul class="subsubsub">
	<?php 
		$count_the_topics = wp_count_posts( 'topic' );
	    $count_topics = number_format_i18n( $count_the_topics->publish );
		$count_the_replies = wp_count_posts( 'reply' );
	    $count_replies = number_format_i18n( $count_the_replies->publish );
	?>
	<li><a href="edit.php?post_type=forum">All Topics <span class="count">(<?php echo $count_topics; ?>)</span></a> |</li>
	<li><a href="edit.php?post_type=reply">All Replies <span class="count">(<?php echo $count_replies; ?>)</span></a></li>
</ul>

<?php
	} else {
		_e( 'There are no forum topics or replies to be found.', 'dashboard-forum-activity' );
	}

}


// Function used in the action hook
function rwi_dashboard_forum_activity_add_dashboard_widgets() {
	
	if ( current_user_can('manage_options') ) { 
	
		wp_add_dashboard_widget('rwi_dashboard_forum_activity', 'Forum Activity', 'rwi_dashboard_forum_activity_output', 'rwi_dashboard_forum_activity_setup' );
		
	} else {
		
		return;
		
	}

}


// Sets up options and their defaults
function rwi_dashboard_forum_activity_options() {
	
	$defaults = array( 'posts_number' => 5 );
	if ( ( !$options = get_option( 'rwi_dashboard_forum_activity' ) ) || !is_array($options) )
		$options = array();
	return array_merge( $defaults, $options );

}


function rwi_dashboard_forum_activity_setup() {
 
	$options = rwi_dashboard_forum_activity_options();
 
	if ( 'post' == strtolower($_SERVER['REQUEST_METHOD']) && isset( $_POST['widget_id'] ) && 'rwi_dashboard_forum_activity' == $_POST['widget_id'] ) {
		foreach ( array( 'posts_number' ) as $key )
				$options[$key] = $_POST[$key];
		update_option( 'rwi_dashboard_forum_activity', $options );
	}
 
?>
 
		<p>
			<label for="posts_number"><?php _e('How many items should display?', 'rwi_dashboard_forum_activity' ); ?>
				<select id="posts_number" name="posts_number">
					<?php for ( $i = 5; $i <= 20; $i = $i + 1 )
						echo "<option value='$i'" . ( $options['posts_number'] == $i ? " selected='selected'" : '' ) . ">$i</option>";
						?>
					</select>
				</label>
 		</p>
 
<?php
 }

// Register the new dashboard widget into the 'wp_dashboard_setup' action
add_action('wp_dashboard_setup', 'rwi_dashboard_forum_activity_add_dashboard_widgets' );

// Adds stylesheet for mint background image
add_action( 'admin_print_styles', 'rwi_dashboard_forum_activity_load_custom_admin_css' );

// The load CSS function
function rwi_dashboard_forum_activity_load_custom_admin_css() {
	wp_enqueue_style( 'rwi_dashboard_forum_activity_custom_admin_css', plugins_url( '/style.css', __FILE__ ) );
}

?>